@@ -5,12 +5,13 @@ use warnings;
 
 use Exporter 'import';
 our @EXPORT = ('bash');
-our @EXPORT_OK = (@EXPORT, 'pwd');
+our @EXPORT_OK = (@EXPORT, qw< pwd head tail >);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-our $VERSION = '0.02_01'; # TRIAL VERSION
+our $VERSION = '0.03_01'; # TRIAL VERSION
 
 
+use Carp;
 use Contextual::Return;
 use Scalar::Util qw< blessed >;
 use IPC::System::Simple qw< run capture EXIT_ANY $EXITVAL >;
@@ -20,7 +21,8 @@ sub _process_bash_arg ()
 {
 	# incoming arg is in $_
 	my $arg = $_;				# make a copy
-	if (blessed $arg and $arg->can('basename'))
+	croak("Use of uninitialized argument to bash") unless defined $arg;
+	if (ref $arg eq 'Regexp' or blessed $arg and $arg->can('basename'))
 	{
 		$arg = "$arg";			# stringify
 		$arg =~ s/'/'\\''/g;	# handle internal single quotes
@@ -30,12 +32,12 @@ sub _process_bash_arg ()
 }
 
 
-sub bash
+sub bash (@)
 {
 	my (@opts, $capture);
 	my $exit_codes = [0..125];
 
-	while ( $_[0] =~ /^-/ or ref $_[0] )
+	while ( $_[0] and ($_[0] =~ /^-/ or ref $_[0]) )
 	{
 		my $arg = shift;
 		if (ref $arg)
@@ -52,6 +54,7 @@ sub bash
 			push @opts, $arg;
 		}
 	}
+	croak("Not enough arguments for bash") unless @_;
 
 	my @cmd = 'bash';
 	push @cmd, @opts;
@@ -100,6 +103,24 @@ use Cwd ();
 *pwd = \&Cwd::cwd;
 
 
+sub head
+{
+	my $num = shift;
+	$num = @_ + $num if $num < 0;
+#warn("# num is $num");
+	@_[0..$num-1];
+}
+
+sub tail
+{
+	my $num = shift;
+	return () unless $num;
+	$num = $num < 0 ? @_ + $num : $num - 1 ;
+#warn("# num is $num");
+	@_[$num..$#_];
+}
+
+
 1;
 
 # ABSTRACT: tighter integration between Perl and bash
@@ -118,7 +139,7 @@ PerlX::bash - tighter integration between Perl and bash
 
 =head1 VERSION
 
-This document describes version 0.02_01 of PerlX::bash.
+This document describes version 0.03_01 of PerlX::bash.
 
 =head1 SYNOPSIS
 
